collectgarbage("stop") -- Stop garbage from being collected so lots of garbage can be built up before a manual collection cycle.

function love.draw()
	local stats = love.graphics.getStats() -- Get texture memory from stats.
	love.graphics.print(
		string.format("Memory: %.2f MB\nTexture Memory: %.2f MB\n\nGarbage collecter stopped.\nHold F to create mesh objects without saving them.\nPress G to run a full collectgarbage cycle.",
			collectgarbage("count")/1024, -- Lua memory.
			stats.texturememory/1024/1024 -- Texture memory. Meshes don't use texture memory, but it's here for viewing anyway.
		),32,32
	)
end

function love.update()
	if love.keyboard.isDown("f") then
		-- Create a garbage mesh each frame. These are not saved anywhere, so they should be collected by the garbage collector.
		local verts = {}
		for i = 1,3000 do
			verts[i] = {
				0,0, -- x,y
				0,0, -- u,v
				0,0,0,0 -- r,g,b,a
			}
		end
		local mesh = love.graphics.newMesh(verts,"triangles","dynamic") -- Mesh draw and usage modes don't seem to affect anything.
	end
end

function love.keypressed(key)
	if key == "g" then
		-- Run a garbage collection cycle, then stop automatic garbage collection again.
		collectgarbage("collect")
		collectgarbage("stop")
	end
end
